PbrBatchesMarker

Struct PbrBatchesMarker 

pub struct PbrBatchesMarker;
Marker component to indicate that an entity should be included in the PBR render batches. This will automatically add the PbrSsboTransformMarker to the entity, so that its transform will be included in the SSBO updates for rendering.