pub struct PbrSsboInstanceToTransform;Expand description
Contains pointers to the transforms of the entities in the SSBO, as well as the offset in the “instance to transform” buffer of the first entity of this batch. This is used to bind the correct transforms to the instances of each batch when rendering.
Implementations
Sourceimpl PbrSsboInstanceToTransform
impl PbrSsboInstanceToTransform
pub const INSTANCE_TO_TRANSFORM_IDX: u32 = 0
pub const INSTANCE_TO_TRANSFORM_STAGING_IDX: u32 = 1