pub struct PbrSsboTransform;Expand description
Contains the transform data for the entities in the scene. See crate::deferred level documentation for more details on how this is used, and how it is updated.
Implementations
Sourceimpl PbrSsboTransform
impl PbrSsboTransform
pub const TRANSFORM_IDX: u32 = 0
pub const TRANSFORM_STAGING_IDX: u32 = 1