pub struct PbrMaterial {
pub label: String,
pub albedo: (f32, f32, f32, f32),
pub albedo_t: Option<Handle<Texture>>,
pub metallic: f32,
pub roughness: f32,
pub metallic_roughness_t: Option<Handle<Texture>>,
pub normal_t: Option<Handle<Texture>>,
pub occlusion_t: Option<Handle<Texture>>,
pub uniform_buffer: Option<Handle<Buffer>>,
}Expand description
Describes a physically based rendering material. It contains the material properties such as albedo color, metallic and roughness intensity, as well as the textures for these properties. It also contains a uniform buffer that is automatically created and updated with the material data, which can be used in the shader to access the material properties. The PbrMaterial3d component is a wrapper around a handle to a PbrMaterial asset, which also adds the [PbrSsboTransformMarker] to the entity, indicating that its transform should be included in the PbrSsboTransform updates.
Fields
label: Stringalbedo: (f32, f32, f32, f32)The albedo color of the material instance (r, g, b). The alpha channel is unused.
albedo_t: Option<Handle<Texture>>The albedo texture of the material instance. If None, the material will use the albedo color.
metallic: f32The metallic intensity of the material instance.
roughness: f32The roughness intensity of the material instance.
metallic_roughness_t: Option<Handle<Texture>>The metallic-roughness texture of the material instance. If None, the material will use the metallic and roughness scalar intensity.
The metallic value is stored in the blue channel, and the roughness value is stored in the green channel.
normal_t: Option<Handle<Texture>>The normal texture of the material instance. The normal map is expected to be in tangent space. The alpha channel is unused.
occlusion_t: Option<Handle<Texture>>The occlusion texture of the material instance. The occlusion value is stored in the red channel.
uniform_buffer: Option<Handle<Buffer>>The buffer containing the material data. It is automatically created and updated if not set.